<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>GrandSearch::AiToolBar</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="48"/>
        <source>Unable to use %1, please go to the App Store to update the UOS AI version first.</source>
        <translation>İşlemi kullanamazsınız, önce UOS AI sürümünü güncellemek için Uygulama Mağazasına gidin.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="49"/>
        <source>Cancel</source>
        <translation type="unfinished">İptal</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="50"/>
        <source>Open App Stroe</source>
        <translation>Uygulama Mağazasını Aç</translation>
    </message>
</context>
<context>
    <name>GrandSearch::AiToolBarInner</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="112"/>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="162"/>
        <source>Summary</source>
        <translation>Özet</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="113"/>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="163"/>
        <source>Translation</source>
        <translation>Çeviri</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="114"/>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="164"/>
        <source>Extension</source>
        <translation>Uzatma</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="115"/>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="165"/>
        <source>Add to knowledge base</source>
        <translation>Bilgi verisine ekle</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="126"/>
        <source>Summarize document content with UOS AI</source>
        <translation>UOS AI ile belge içeriğini özetleyin</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="127"/>
        <source>Translate document content with UOS AI</source>
        <translation>UOS AI ile belge içeriğini çevirin</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="128"/>
        <source>Extend document content with UOS AI</source>
        <translation>UOS AI ile belge içeriğini uzatın</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="129"/>
        <source>Add document to UOS AI knowledge base</source>
        <translation>Belgeyi UOS AI bilgi verisine ekleyin</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="299"/>
        <source>Summarize this document for me and provide me with a clear result directly, without any unnecessary content.</source>
        <translation>Bu belgenin özetini bana verin ve doğrudan net bir sonuç sunun, gereksiz içeriklerden kaçının.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="315"/>
        <source>Translate this document for me and provide me with a clear result directly, without any unnecessary content.</source>
        <translation>Bu belgenin çevirisini bana verin ve doğrudan net bir sonuç sunun, gereksiz içeriklerden kaçının.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="331"/>
        <source>Expand this document for me and provide me with a clear and expanded result directly, without any unnecessary content.</source>
        <translation>Bu belgenin genişletilmiş bir versiyonunu bana verin ve doğrudan açık ve genişletilmiş bir sonuç sunun, gereksiz içeriklerden kaçının.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="447"/>
        <source>DDE Grand Search</source>
        <translation>DDE Grand Search</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="450"/>
        <source>Unable to use %1, please go to the App Store to update the UOS AI version first.</source>
        <translation>İşlemi kullanamazsınız, önce UOS AI sürümünü güncellemek için Uygulama Mağazasına gidin.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="451"/>
        <source>Open App Stroe</source>
        <translation>Uygulama Mağazasını Aç</translation>
    </message>
</context>
<context>
    <name>GrandSearch::BestMatchWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/bestmatchwidget.cpp" line="28"/>
        <source>Best match</source>
        <translation>En uygun eşleşme</translation>
    </message>
</context>
<context>
    <name>GrandSearch::BlackListWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistwidget.cpp" line="32"/>
        <source>Excluded path</source>
        <translation>Dışarı atılan yol</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistwidget.cpp" line="43"/>
        <source>Add paths to the exclusion list to prevent searching in them.</source>
        <translation>Arama yapmamak için dışarı atılan yollar listesine yollar ekleyin.</translation>
    </message>
</context>
<context>
    <name>GrandSearch::CustomWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/customwidget.cpp" line="31"/>
        <source>Custom search</source>
        <translation>Özel arama</translation>
    </message>
</context>
<context>
    <name>GrandSearch::DdeGrandSearchDockPlugin</name>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="49"/>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="122"/>
        <source>Grand Search</source>
        <translation>Büyük Ara</translation>
    </message>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="201"/>
        <source>Search settings</source>
        <translation>Arama ayarları</translation>
    </message>
</context>
<context>
    <name>GrandSearch::DeleteDialog</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="14"/>
        <source>Do you want to remove the path from the exclusion list?</source>
        <translation>Yolun dışarı atılan yollar listesinden kaldırılmak istiyor musunuz?</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="20"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="28"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Onayla</translation>
    </message>
</context>
<context>
    <name>GrandSearch::EmbeddingPluginWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/embeddingpluginwidget.cpp" line="52"/>
        <source>Installed</source>
        <translation>Yüklenmiştir</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/embeddingpluginwidget.cpp" line="52"/>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/embeddingpluginwidget.cpp" line="90"/>
        <source>Not Installed</source>
        <translation>Yüklenmemiştir</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/embeddingpluginwidget.cpp" line="105"/>
        <source>Install</source>
        <translation>Yükle</translation>
    </message>
</context>
<context>
    <name>GrandSearch::EntranceWidget</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="237"/>
        <source>Search</source>
        <translation>Arama</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="238"/>
        <source>What would you like to search for?</source>
        <translation>Ne aramak istersin?</translation>
    </message>
</context>
<context>
    <name>GrandSearch::EntranceWidgetPrivate</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="82"/>
        <source>Cut</source>
        <translation>Kes</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="86"/>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="90"/>
        <source>Paste</source>
        <translation>Yapıştır</translation>
    </message>
</context>
<context>
    <name>GrandSearch::GeneralPreviewPlugin</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="193"/>
        <source>Location:</source>
        <translation>Konum:</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="204"/>
        <source>Time modified:</source>
        <translation>Zaman değiştirildi:</translation>
    </message>
</context>
<context>
    <name>GrandSearch::GeneralToolBar</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="70"/>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="75"/>
        <source>Open Path</source>
        <translation>Yolu Aç</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="80"/>
        <source>Copy Path</source>
        <translation>Yolu Kopyala</translation>
    </message>
</context>
<context>
    <name>GrandSearch::GroupWidget</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="269"/>
        <source>Please go to %1 to install the ULLM, and %2 Automatic index update.</source>
        <translation>Lütfen %1 adresine gidin ve ULLM&apos;yi yükleyin, %2 Otomatik indeks güncelleme.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="270"/>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="279"/>
        <source>Search configration</source>
        <translation>Arama yapılandırması</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="271"/>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="275"/>
        <source>turn on</source>
        <translation>aç</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="274"/>
        <source>Please %1 Automatic index update.</source>
        <translation>Lütfen %1 Otomatik indeks güncelleme.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="278"/>
        <source>Please go to %1 to install the ULLM.</source>
        <translation>Lütfen %1 adresine gidin ve ULLM&apos;yi yükleyin.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="330"/>
        <source>More</source>
        <translation>Daha fazla</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="281"/>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="366"/>
        <source>No search results</source>
        <translation type="unfinished">Arama sonucu bulunamadı</translation>
    </message>
</context>
<context>
    <name>GrandSearch::IndexWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/indexwidget.cpp" line="30"/>
        <source>Index</source>
        <translation>dizin</translation>
    </message>
</context>
<context>
    <name>GrandSearch::IntelligentRetrievalWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="66"/>
        <source>AI Smart Search</source>
        <translation>AI Akıllı Arama</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="79"/>
        <source>When turned on, you can try to search for local documents using natural language descriptions, such as &quot;last week&apos;s documents&quot;.</source>
        <translation>Açıldığında, doğal dille tanımlanan belgeleri (örneğin &quot;geçen hafta belgeleri&quot;) kullanarak yerel belgeleri aramaya çalışabilirsiniz.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="100"/>
        <source>Automatic index update</source>
        <translation>Otomatik indeks güncelleme</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="119"/>
        <source>Full Text Search</source>
        <translation>Tam Metin Araması</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="136"/>
        <source>When turned on, full text search can be used in the file manager and grand search.</source>
        <translation>Açık bırakıldığında, tam metin arama dosya yöneticisinde ve grand aramada kullanılabilir.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="154"/>
        <source>Embedding Plugins</source>
        <translation>Ekleme Eklentileri</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="154"/>
        <source>After installing the model, you can use services such as AI Search and UOS AI Assistant..</source>
        <translation>Model kurulumu完成后, AI Arama ve UOS AI Yardımcısı gibi hizmetleri kullanabilirsiniz.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="172"/>
        <source>ULLM</source>
        <translation>ULLM</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="172"/>
        <source>After installing the ULLM, you can use the AI intelligent search function without an internet connection.</source>
        <translation>ULLM kurulumu完成后, internet bağlantısı olmadan AI zeki arama işlevini kullanabilirsiniz.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="185"/>
        <source>Intelligent full text search</source>
        <translation>Zeki tam metin arama</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="221"/>
        <source>When enabled, you can search the text of articles using disjointed and incomplete keywords.</source>
        <translation>Etkinleştirildiğinde, parçalı ve eksik anahtar kelimeleri kullanarak makalelerin metnini arayabilirsiniz.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="243"/>
        <source>Please install %0 in &lt;a href=&quot;%0&quot;&gt;the app store&lt;/a&gt; before turning on this configuration.</source>
        <translation>Lütfen bu yapılandırmayı açmadan önce &quot;%0&quot; &lt;a href=&quot;%0&quot;&gt;uygulama mağazasında&lt;/a&gt; kurun.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="283"/>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="407"/>
        <source>Intelligent search indexing is being updated, which may take up more resources, please keep the power access.</source>
        <translation>Zeki arama indeksleme güncelleniyor, bu daha fazla kaynak tüketebilir, lütfen güç erişimini koruyun.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="287"/>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="411"/>
        <source>Smart Search indexing update is complete. Last update time: %0</source>
        <translation>Akıllı Arama indeksleme güncelleme tamamlandı. Son güncelleme zamanı: %0</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="290"/>
        <source>Indexing error!</source>
        <translation>İndeksleme hatası!</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="339"/>
        <source>To use AI Smart Search, you need to install the Embedding Plugins and ULLM first.</source>
        <translation>AI Akıllı Arama kullanmak için önce Ekleme Eklentileri ve ULLM kurulumu gerekir.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="340"/>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
</context>
<context>
    <name>GrandSearch::LLMWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="61"/>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="385"/>
        <source>Not Installed</source>
        <translation>Kurulum Yapılmadı</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="77"/>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="384"/>
        <source>Install Model</source>
        <translation>Model Kur</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="93"/>
        <source>Update model</source>
        <translation>Modeli Güncelle</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="94"/>
        <source>Uninstall model</source>
        <translation>Modeli Kaldır</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="146"/>
        <source>Installing</source>
        <translation>Kurulum Yapılıyor</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="212"/>
        <source>Are you sure you want to delete this model?</source>
        <translation>Bu modeli silmek istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="213"/>
        <source>After uninstallation, functions such as AI Search and UOS AI Assistant will not work properly.</source>
        <translation>Kaldırıldıktan sonra AI Arama ve UOS AI Yardımcısı gibi işlevler düzgün çalışmayacaktır.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="214"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">İptal</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="215"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation type="unfinished">Onayla</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="324"/>
        <source>Installing </source>
        <translation>Kurulum Yapılıyor </translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="344"/>
        <source>Installing the ULLM</source>
        <translation>ULLM Kurulumu</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="345"/>
        <source>Exiting will cause the installation to fail, do you still want to exit?</source>
        <translation>Çıkış yapmak kurulumu başarısız kılacaktır, hâlâ çıkmak istiyorsunuz mu?</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="346"/>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Çıkış</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="347"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Devam</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="378"/>
        <source>UnInstall Model</source>
        <translation>Modeli Kaldır</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="379"/>
        <source>Installed</source>
        <translation>Kuruldu</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="390"/>
        <source>Please install the &quot;Embedding Plugins&quot; first before installing this model.</source>
        <translation>Lütfen önce &quot;Ekleme Eklentileri&quot; kurulumu yapın, sonra bu modeli kurun.</translation>
    </message>
</context>
<context>
    <name>GrandSearch::MainWindow</name>
    <message>
        <location filename="../src/grand-search/gui/mainwindow.cpp" line="222"/>
        <source>No search results</source>
        <translation>Arama sonucu bulunamadı</translation>
    </message>
</context>
<context>
    <name>GrandSearch::MatchWidget</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/matchwidget.cpp" line="89"/>
        <source>Guess you want to search the following</source>
        <translation>İşte aramak istediğiniz şeyleri tahmin ediyoruz</translation>
    </message>
</context>
<context>
    <name>GrandSearch::PlanWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="32"/>
        <source>Search experience program</source>
        <translation>Arama deneyimi programı</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="40"/>
        <source>Join search experience program</source>
        <translation>Arama deneyimi programına katılın</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="53"/>
        <source>Joining the search experience program means that you grant and authorize us to collect the information of your device and system, file icons, content and properties, applications and their configurations, the contents you search while using the Application, the time of search, the type of requested large model.If you refuse our collection and use of the aforementioned information, do not join the program.</source>
        <translation>Arama deneyimi programına katılmak, cihazınız ve sisteminizin bilgilerini, dosya simgelerini, içerik ve özellikleri, uygulamalar ve yapılandırmalarını, uygulama kullanırken arama yaptığınız içerikleri, arama zamanını ve istenen büyük model türüne izin vermek anlamına gelir. Bu bilgilerin toplanması ve kullanılmasına izin vermiyorsanız, programı katılmayın.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="64"/>
        <source>To know more about the management of your data, please refer to the UnionTech Software Privacy Policy (</source>
        <translation>Verilerinizin yönetimi hakkında daha fazla bilgi için lütfen UnionTech Yazılım Gizlilik Politikasına bakın (</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="66"/>
        <source>https://www.uniontech.com/agreement/privacy-en</source>
        <translation>https://www.uniontech.com/agreement/privacy-en</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="67"/>
        <source>https://www.deepin.org/en/agreement/privacy/</source>
        <translation>https://www.deepin.org/en/agreement/privacy/</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="69"/>
        <source>).</source>
        <translation>).</translation>
    </message>
</context>
<context>
    <name>GrandSearch::ScopeWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/scopewidget.cpp" line="33"/>
        <source>Search contents</source>
        <translation>İçerikler ara</translation>
    </message>
</context>
<context>
    <name>GrandSearch::SearchEngineWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="42"/>
        <source>Default search engine</source>
        <translation>Varsayılan arama motoru</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="50"/>
        <source>Search for keywords by the default search engine.</source>
        <translation>Varsayılan arama motoruyla anahtar kelimeleri arayın.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="62"/>
        <source>Default search engine is</source>
        <translation>Varsayılan arama motoru</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="71"/>
        <source>Google</source>
        <translation>Google</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="72"/>
        <source>Baidu</source>
        <translation>Baidu</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="73"/>
        <source>Bing</source>
        <translation>Bing</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="74"/>
        <source>Yahoo</source>
        <translation>Yahoo</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="75"/>
        <source>360</source>
        <translation>360</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="76"/>
        <source>360 AI Search</source>
        <translation>360 AI Arama</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="77"/>
        <source>Sogou</source>
        <translation>Sogou</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="78"/>
        <source>Custom</source>
        <translation>Özelleştirilmiş</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="99"/>
        <source>You need to use &quot;%0&quot; to replace the keyword in the URL</source>
        <translation>URL&apos;deki anahtar sözcüğü &quot;%0&quot; ile değiştirmeniz gerekir</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="167"/>
        <source>Invalid URL</source>
        <translation>Geçersiz URL</translation>
    </message>
</context>
<context>
    <name>GrandSearch::StaticTextWorker</name>
    <message>
        <location filename="../src/dde-grand-search-daemon/searcher/web/statictextworker.cpp" line="66"/>
        <source>Search for &quot;%1&quot;</source>
        <translation>&quot;%1&quot; için ara</translation>
    </message>
</context>
<context>
    <name>GrandSearch::TailerWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="19"/>
        <source>Tailer settings</source>
        <translation>Satıcı ayarları</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="29"/>
        <source>It is displayed at the end of search results for better identification and distinction of items with duplicate names.</source>
        <translation>Yinelenen ada sahip öğelerin daha iyi tanımlanması ve ayırt edilmesi için arama sonuçlarının sonunda görüntülenir.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="38"/>
        <source>Parent directory</source>
        <translation>Üst dizin</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="40"/>
        <source>Time modified</source>
        <translation>Zaman değiştirildi</translation>
    </message>
</context>
<context>
    <name>GrandSearch::audio_preview::AudioPreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="70"/>
        <source>Artist:</source>
        <translation>Sanatçı:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="82"/>
        <source>Album:</source>
        <translation>Albüm:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="107"/>
        <source>Duration:</source>
        <translation>Süre:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="122"/>
        <source>Type:</source>
        <translation>Tür:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="134"/>
        <source>Location:</source>
        <translation>Konum:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="148"/>
        <source>Time modified:</source>
        <translation>Zaman değiştirildi:</translation>
    </message>
</context>
<context>
    <name>GrandSearch::image_preview::ImagePreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="65"/>
        <source>Dimensions:</source>
        <translation>Boyutlar:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="81"/>
        <source>Type:</source>
        <translation>Tür:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="96"/>
        <source>Size:</source>
        <translation>Boyut:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="108"/>
        <source>Location:</source>
        <translation>Konum:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="122"/>
        <source>Time modified:</source>
        <translation>Zaman değiştirildi:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="24"/>
        <source>Best match</source>
        <translation>En uygun eşleşme</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="25"/>
        <source>Applications</source>
        <translation>Uygulamalar</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="26"/>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="27"/>
        <source>Videos</source>
        <translation>Videolar</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="28"/>
        <source>Music</source>
        <translation>Müzik</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="29"/>
        <source>Pictures</source>
        <translation>Resimler</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="30"/>
        <source>Documents</source>
        <translation>Belgeler</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="31"/>
        <source>Folders</source>
        <translation>Klasörler</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="32"/>
        <source>Files</source>
        <translation>Dosyalar</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="33"/>
        <source>Web</source>
        <translation>Ağ</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="34"/>
        <source>AI Search</source>
        <translation>AI Arama</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="28"/>
        <source>Dimensions:</source>
        <translation>Boyutlar:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="29"/>
        <source>Type:</source>
        <translation>Tür:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="30"/>
        <source>Size:</source>
        <translation>Boyut:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="31"/>
        <source>Duration:</source>
        <translation>Süre:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="32"/>
        <source>Location:</source>
        <translation>Konum:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="33"/>
        <source>Time modified:</source>
        <translation>Zaman değiştirildi:</translation>
    </message>
    <message>
        <location filename="../src/dde-grand-search-daemon/searcher/file/filesearchutils.cpp" line="205"/>
        <source>modified</source>
        <translation>değiştirildi</translation>
    </message>
</context>
<context>
    <name>searchitem</name>
    <message>
        <location filename="../src/grand-search-shell-plugin/package/searchitem.qml" line="24"/>
        <source>GrandSearch</source>
        <translation>GrandSearch</translation>
    </message>
    <message>
        <location filename="../src/grand-search-shell-plugin/package/searchitem.qml" line="81"/>
        <source>SearchConfig</source>
        <translation>AramaKonfigürasyonu</translation>
    </message>
</context>
</TS>
